import bb.cascades 1.2
import bb.system 1.0
import "Actions"
import "DropDown"

Page {
    id: settingsPage
    
    property bool debugModeOn: _settings.value("sendToConsoleDebug", false)
        
    titleBar: TitleBar {
        title: qsTr("Settings")
    }

    actions: [
//        ReviewActionOnBarOrSignature {},
//        ShareAction {}
        TutorialAction {}
    ]
    
    attachedObjects: [
        Invocation {
            id: settingsInvoke
            onArmed: {
                trigger(query.invokeActionId)
            }
        }
    ]
    
    Container {
        id: mainContainer
        layout: DockLayout {}
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        topPadding: navigationPane.generalPadding
        leftPadding: topPadding
        rightPadding: topPadding
        bottomPadding: topPadding
        
        property double numberOfDoubleTaps: 0
        
        gestureHandlers: [
            DoubleTapHandler {
                onDoubleTapped: {
                    mainContainer.numberOfDoubleTaps++
                    if (mainContainer.numberOfDoubleTaps == 2) {
                        mainContainer.numberOfDoubleTaps = 0
                        _settings.setValue("sendToConsoleDebug", !_settings.value("sendToConsoleDebug", false))
                        _app.setEnvironment("SEND_TO_CONSOLEDEBUG", _settings.value("sendToConsoleDebug", false).toString());
                        settingsPage.debugModeOn = _settings.value("sendToConsoleDebug", false)
                        systemToast.body = qsTr("ConsoleDebug mode set to ") + (_settings.value("sendToConsoleDebug", false) ? qsTr("ON") : qsTr("OFF"))
                        systemToast.show()
                    }
                }
                attachedObjects: [
                    SystemToast {
                        id: systemToast
                    }
                ]
            }
        ]
        
        ScrollView {
            Container {
                Header { title: qsTr("Watchface Settings") }
                ShowWeatherDropDown { id: showWeatherDropDown }
                CelsiusOrFarenheitDropDown { visible: showWeatherDropDown.showWeather }
                WeatherServiceDropDown { visible: showWeatherDropDown.showWeather }
                GpsOrPlaceDropDown { 
                    id: gpsOrPlaceDropDown 
                    visible: showWeatherDropDown.showWeather 
                }
                PlaceSelection { visible: (gpsOrPlaceDropDown.thisValue == "Place") }
                ShowCalendarDropDown {id: calendarDropDown }
                CalendarMinutesToCheckDropDown { /* visible: calendarDropDown.showCalendar */ }
                HideReadAccountsDropDown {}
                VibrateOnUnreadDropDown { id: vibrateOnUnreadDropDown }
                NumberOfVibrationsDropDown { visible: (vibrateOnUnreadDropDown.vibrateOnUnread != "disabled") }
                DisableVibeIfScreenIsOnDropDown { visible: (vibrateOnUnreadDropDown.vibrateOnUnread != "disabled") }
                WristShakeEnabledDropDown {}
                Header { title: qsTr("Hub Accounts To Monitor") }
                AccountsSelected {}
                Header { title: qsTr("App Settings") }
                IsDarkThemeDropDown {}
//                Header { title: qsTr("Tutorial") }
//                RerunTutorial {}
//                Header { title: qsTr("Problem With 30.0.2.5?") }
//                TemporaryFixDropDown {}
                Header { title: qsTr("Extra features (unsupported)") }
                Label {
                    text: qsTr("Send Pebble battery level to Hub whenever it changes, so you'll know how much juice you have and how long you can expect your watch to last.") + Retranslate.onLocaleOrLanguageChanged
                    multiline: true
                }
                ShowPebbleBatteryDropDown {}
                Button {
                    text: qsTr("Send Pebble battery info right now")
                    onClicked: _app.sendToHeadless("SEND_BATTERY_INFO")
                }
                Container {
                    topPadding: _ui.du(3)
                    Label {
                        text: qsTr("VIP feature will add a VIP icon whenever a selected BBM contact sends you a message. To select one (or more) BBM contact, enable VIP Mode and VIP Learning Mode and go write a random message to that contact. There will be a notification asking you to tap it to add to VIP list. Once done, come back here and disable VIP Learning Mode but keep VIP Mode enabled if you want to have the VIP icon on your watch when that special someone sends you a message. To remove someone from VIP list, do the exact same steps.") + Retranslate.onLocaleOrLanguageChanged
                        multiline: true
                    }
                }
                VipModeOnDropDown { id: vipModeOnDropDown }
                VipLearningModeOnDropDown { visible: vipModeOnDropDown.vipModeOn }
                Button {
                    text: qsTr("Delete all VIP")
                    onClicked: {
                        _settings.setValue("vipList", "")
                        deleteVipToast.show()
                    }
                    attachedObjects: [
                        SystemToast {
                            id: deleteVipToast
                            body: qsTr("All VIP were deleted")
                        }
                    ]
                }
                Container {
                    visible: settingsPage.debugModeOn
                    Header { title: qsTr("Developer options") }
                    Button {
                        text: qsTr("Shutdown")
                        onClicked: {
                            _app.sendToHeadless("SHUTDOWN")
                        }
                    }
                    Button {
                        text: qsTr("Clear Settings")
                        onClicked: {
                            _app.clearSettings()
                        }
                    }
                    AutoChangeWatchfaceDropDown { visible: false }
                }
            }
        }
    }            
}         
