import bb.cascades 1.2
import bb.system 1.2

Sheet {
    id: tutorialSheet
    onOpened: {
        listView.scrollToItem([0], ScrollAnimation.Smooth)
        listView.sheetOpened = true
        navigationPane.tutorialOpened = true
        _fileSystem.checkIfPebbleExist()
    }
    onClosed: {
        listView.sheetOpened = false
        navigationPane.tutorialOpened = false
        watchfaceSelectionSheet.open()
    }
    
    onCreationCompleted: {
        _fileSystem.pebbleExistCheckDone.connect(onPebbleExistCheckDone)
    }
    
    function onPebbleExistCheckDone(pebbleExist) {
        if (pebbleExist) {
            systemToast.body = qsTr("Pebble watch found!")
            systemToast.show()
        }
        else {
            systemToast.body = qsTr("No Pebble watch found. This app is useless without a Pebble.")
            systemToast.button.label = qsTr("Ok")
            systemToast.show()
        }
    }
    
    attachedObjects: [
        SystemToast {
            id: systemToast
        }
    ]
    
    Page {
        id: tutorialPage
        titleBar: TitleBar {
            id: titleBar
            title: qsTr("Instructions")
            acceptAction: ActionItem {
                title: tutorialPage.pageShown == (listView.dataModel.childCount([]) - 1) ? qsTr("Done") : qsTr("Next")
                onTriggered: {
                    //listView.dataModel.childCount([])                    
                    if (tutorialPage.pageShown == (listView.dataModel.childCount([])) - 1) {
                        if (_settings.value("showFirstTimeTutorial", true))
                            _settings.setValue("showFirstTimeTutorial", false)
                            
                        tutorialSheet.close()
                    }
                    else 
                        listView.scrollToItem([tutorialPage.pageShown + 1], ScrollAnimation.Smooth)
                }
            }
            dismissAction: ActionItem {
                title: qsTr("Cancel")
                onTriggered: {
                    tutorialSheet.close()
                }
            }
        }
                
        property int pageShown
        
        Container {
            id: tutorialContainer
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            attachedObjects: LayoutUpdateHandler {
                id: luhContainer
            }
            topPadding: luhContainer.layoutFrame.height * 0.05
            bottomPadding: topPadding
            leftPadding: luhContainer.layoutFrame.width * 0.05
            rightPadding: leftPadding
            background: Color.DarkGray
            ListView {
                id: listView
                
                property int deviceWidth: luhContainer.layoutFrame.width * 0.90
                property int deviceHeight: luhContainer.layoutFrame.height * 0.90
                property int itemLeftPadding: luhContainer.layoutFrame.width * 0.05
                property int itemTopPadding: luhContainer.layoutFrame.height * 0.05
                property bool sheetOpened
                property variant background: tutorialContainer.background

                attachedObjects: [
                    Invocation {
                        id: t2wInvocation
                        onArmed: {
                            trigger(query.invokeActionId)
                        }
                    }
                ]
                
                function buttonClicked(page) {
                    _app.sendToHeadless("AUTHORIZE")
                    listView.scrollToItem([tutorialPage.pageShown + 1], ScrollAnimation.Smooth)
                }
                
                scrollRole: navigationPane.tutorialOpened ? ScrollRole.Main : ScrollRole.None
                dataModel: XmlDataModel { source: qsTr("asset:///Tutorial/tutorialModel.xml") }
                layout: StackListLayout { orientation: LayoutOrientation.LeftToRight }
                flickMode: FlickMode.SingleItem
                
                function updatePageShown(page) {
                    tutorialPage.pageShown = page
                }
                
                listItemComponents: [
                    ListItemComponent {
                        type: "item"
                        Container {
                            id: itemContainer
                            layout: DockLayout {}
                            preferredWidth: itemContainer.ListItem.view.deviceWidth
                            preferredHeight: itemContainer.ListItem.view.deviceHeight
                            attachedObjects: LayoutUpdateHandler {
                                id: luhPosition
                                onLayoutFrameChanged: {
                                    if (luhPosition.layoutFrame.x >= - itemContainer.preferredWidth / 2 && luhPosition.layoutFrame.x <= itemContainer.preferredWidth / 2) {
                                        itemContainer.ListItem.view.updatePageShown(ListItemData.page)
                                    } 
                                }
                            }
                            Container {
                                layout: DockLayout {}
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Fill
                                ImageView {
                                    imageSource: ListItemData.image
                                    horizontalAlignment: HorizontalAlignment.Center
                                    verticalAlignment: VerticalAlignment.Top
                                    maxHeight: itemContainer.ListItem.view.deviceHeight * 0.75
                                    maxWidth: maxWidth
                                    scalingMethod: ScalingMethod.AspectFit
                                }
                                Container {
                                    horizontalAlignment: HorizontalAlignment.Fill
                                    verticalAlignment: (ListItemData.image != "") ? VerticalAlignment.Bottom : VerticalAlignment.Center
                                    opacity: 0.9
                                    background: itemContainer.ListItem.view.background
                                    Label {
                                        text: ListItemData.description
                                        multiline: true
                                        textStyle.fontSize: FontSize.XLarge
                                        horizontalAlignment: HorizontalAlignment.Center
                                        textStyle.color: Color.White
                                    }
                                    Button {
                                        text: ListItemData.buttonText
                                        visible: (text != "")
                                        horizontalAlignment: HorizontalAlignment.Center
                                        onClicked: {
                                            itemContainer.ListItem.view.buttonClicked(ListItemData.page)
                                        }
                                    }
                                }
                            }
                        }
                    }
                ]    
            }
        }
    }
}
