import bb.cascades 1.2
import QTimer 1.0
import "Watchfaces"

Sheet {
    id: watchfaceSelectionSheet
    
    property string baseUuid: "28af3dc7e40d490fbef229548c8beee"
    
    onOpened: { moveListViewTimer.start() }
    onClosed: { moveListViewTimer.stop() }
    
    Page {
        titleBar: TitleBar {
            title: qsTr("Choose A Watchface")
            dismissAction: ActionItem {
                title: qsTr("Close")
                onTriggered: {
                    watchfaceSelectionSheet.close()
                }
            }
        }

        Container {
            leftPadding: navigationPane.generalPadding
            rightPadding: leftPadding
            background: Color.LightGray
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            Container {
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Center
                Container {
                    bottomPadding: _ui.du(5)
                    horizontalAlignment: HorizontalAlignment.Center
                    Label { 
                        text: qsTr("Watchfaces available for Black&White Pebble AND Color Pebble") 
                        textStyle.color: Color.Black
                        textStyle.fontStyle: FontStyle.Italic
                        textStyle.fontWeight: FontWeight.Bold
                        multiline: true
                    }
                }
                ListView {
                    id: listView
                    
                    property int iterator: 0
                    property string publicDir: _publicDir
                    
                    dataModel: XmlDataModel { source: "asset:///Watchfaces/model.xml" }
                    layout: StackListLayout { orientation: LayoutOrientation.LeftToRight }
                    preferredHeight: _ui.du(60)
                    maxHeight: preferredHeight
                    horizontalAlignment: HorizontalAlignment.Center
//                flickMode: FlickMode.SingleItem
                    
                    onTouch: {
                        moveListViewTimer.stop()
                    }
                    
                    function buttonClick(watchfaceNumber) {
//                        t2wInvocation.query.invokeActionId = "bb.action.SHARE"
//                        t2wInvocation.query.invokeTargetId = "com.Talk2WatchPro"
                        t2wInvocation.query.invokeActionId = "bb.action.OPEN"
                        t2wInvocation.query.uri = _publicDir + "assets/Watchfaces/Hub2Watch_" + watchfaceNumber + ".pbw"
                        t2wInvocation.query.updateQuery()
                        _app.sendToHeadless("WATCHFACE_INSTALLED", watchfaceSelectionSheet.baseUuid + watchfaceNumber)
                        watchfaceSelectionSheet.close()
                    }
                    
                    function pebbleButtonClick(pebbleId, watchfaceNumber) {
                        _app.installWatchfaceWithBridge(pebbleId)
                        _app.sendToHeadless("WATCHFACE_INSTALLED", baseUuid + watchfaceNumber)
                        watchfaceSelectionSheet.close()
                    }
                    
                    function du(unit) {
                        return _ui.du(unit)
                    }
                    
                    attachedObjects: [
                        QTimer {
                            id: moveListViewTimer
                            interval: 3000
                            onTimeout: {
                                listView.iterator++
                                
                                if (listView.iterator == listView.dataModel.childCount([]))
                                    listView.iterator = 0
                                
                                listView.scrollToItem([listView.iterator], ScrollAnimation.Smooth)
                                
                                if (listView.iterator == 0)
                                    interval = 3500
                                else 
                                    interval = 3000
                            }
                        },
                        Invocation {
                            id: t2wInvocation
                            onArmed: { trigger(query.invokeActionId) }
                        }
                    ]  
                    
                    listItemComponents: [
                        ListItemComponent {
                            type: "item"
                            Container {
                                id: itemContainer
                                preferredHeight: itemContainer.ListItem.view.maxHeight
                                minWidth: itemContainer.ListItem.view.du(50)
                                Container {
                                    property string baseUuid: "28af3dc7e40d490fbef229548c8beee"
                                    
                                    Label {
                                        text: ListItemData.watchfaceName
                                        horizontalAlignment: HorizontalAlignment.Center
                                        textStyle.color: Color.Black
                                        multiline: true
                                    }
                                    ImageView { 
                                        id: imageView 
                                        horizontalAlignment: HorizontalAlignment.Fill
                                        imageSource: "asset:///Watchfaces/Hub2Watch_" + ListItemData.watchfaceNumber + ".png"
                                        scalingMethod: ScalingMethod.AspectFit
                                        minHeight: itemContainer.ListItem.view.du(28.8)
                                        minWidth: itemContainer.ListItem.view.du(33.6)
                                    }
                                    Button {
                                        text: qsTr("Install with Bridge")
                                        horizontalAlignment: HorizontalAlignment.Fill
                                        onTouch: {
                                            if (event.touchType == TouchType.Up)
                                                itemContainer.ListItem.view.pebbleButtonClick(ListItemData.pebbleId, ListItemData.watchfaceNumber)
                                        }
                                    }
                                    
                                    Button {
                                        text: qsTr("Install with Talk2Watch")
                                        horizontalAlignment: HorizontalAlignment.Fill
                                        onTouch: {
                                            if (event.touchType == TouchType.Up)
                                                itemContainer.ListItem.view.buttonClick(ListItemData.watchfaceNumber)
                                        }
                                    }
                                    
                                    /*
                                    Button {
                                        visible: (ListItemData.watchappEnabled == "true")
                                        text: qsTr("Install this watchapp")
                                        horizontalAlignment: HorizontalAlignment.Fill
                                        onTouch: {
                                            if (event.touchType == TouchType.Up)
                                                itemContainer.ListItem.view.buttonClick(ListItemData.watchfaceNumber + "_app")
                                        }
                                    }
                                    */
                                }
                            }
                        }
                    ]
                }
            }
        }    
    }
}
