/*
 * Copyright (c) 2013-2014 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.2
import bb.system 1.2
import "Tutorial"

NavigationPane {
    id: navigationPane
    
    property bool isDarkTheme: _settings.value("isDarkThemeDropDown", true)
    property double generalPadding: _ui.du(1)
    property bool tutorialOpened: false
    
    onCreationCompleted: {
        _app.sendToHeadless("START", "")
    }
    
    Menu.definition: MenuDefinition {
        settingsAction: SettingsActionItem {
            onTriggered: {
                menu.source = "SettingsPage.qml";
                var page = menu.createObject();
                
                // Push the new Page.
                Application.menuEnabled = false;
                navigationPane.push(page);
            }
        }
        actions: [
            ActionItem {
                title: qsTr("Help")
                ActionBar.placement: ActionBarPlacement.OnBar
                imageSource: "asset:///images/icons/ic_help.png"
                onTriggered: {
                    menu.source = "HelpPage.qml";
                    var page = menu.createObject();
                    
                    // Push the new Page.
                    Application.menuEnabled = false;
                    navigationPane.push(page);
                }
            },
            ActionItem {
                title: qsTr("About")
                ActionBar.placement: ActionBarPlacement.OnBar
                imageSource: "asset:///images/icons/ic_info.png"
                onTriggered: {
                    menu.source = "AboutPage.qml";
                    var page = menu.createObject();
                    
                    // Push the new Page.
                    Application.menuEnabled = false;
                    navigationPane.push(page);
                }
            },
            ActionItem {
                title: qsTr("Watchfaces")
                ActionBar.placement: ActionBarPlacement.OnBar
                imageSource: "asset:///images/icons/blue_pebble.png"
                onTriggered: {
                    watchfaceSelectionSheet.open()
                }
            }
        ]      
    }

    onPopTransitionEnded: {
        page.destroy();
        
        Application.menuEnabled = true
    }

    attachedObjects: [
        WatchfaceSelectionSheet {
            id: watchfaceSelectionSheet
        }
    ]

    Page {
        onCreationCompleted: {
            Application.setCover(activeFrame)
            _app.newUdpData.connect(onUdpData)
            _app.updateRequired.connect(onUpdateRequired)
            _app.newChangelog.connect(onNewChangelog)
            
            if ((!_settings.value("isBetaVersion", true)) && (_settings.value("showFirstTimeTutorial", true)))
                tutorialSheet.open()
        }
        
        function onUdpData(data) {
            label.text = data 
            activeFrame.labelText = data
        }
        
        function onUpdateRequired(version, minimumVersion) {
            updateDialog.body = qsTr("This app needs Talk2Watch Pro " + minimumVersion + " or later installed. (This check is only done at startup)")
            if (version == "0") 
                updateDialog.title = qsTr("You don't have Talk2Watch Pro")
            else 
                updateDialog.title = qsTr("Talk2Watch Pro ") + version + qsTr(" detected")
//            updateDialog.show()
        }
        
        function onNewChangelog(newChangelogForThisUser) {
            changelogContainer.changelogText = "Changelog:\n" + newChangelogForThisUser
            changelogContainer.visible = true
        }
        
        attachedObjects: [
            AppCover { id: activeFrame },
            SettingsPage { id: settingsPage },
            TutorialSheet { id: tutorialSheet },
            ComponentDefinition { id: menu },
            SystemDialog {
                id: updateDialog
                confirmButton.label: qsTr("Install")
                cancelButton.label: qsTr("Later")
                onFinished: {
                    if (buttonSelection() == confirmButton) {
                        bbwT2wInstall.query.invokeTargetId = "sys.appworld"
                        bbwT2wInstall.query.invokeActionId = "bb.action.OPEN"
                        bbwT2wInstall.query.uri = "appworld://content/47592888"
                        bbwT2wInstall.query.updateQuery()
                    }
                }
            },
            Invocation {
                id: bbwT2wInstall
                onArmed: {
                    trigger(query.invokeActionId)
                }
            }
        ]
        
        Container {
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            ChangelogContainer { id: changelogContainer; visible: false; }
            ScrollView {
                visible: !changelogContainer.visible
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                Container {
                    layout: DockLayout {}
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    Label {
                        id: label
                        visible: (text != "")
                        multiline: true
                        textStyle.fontSize: FontSize.XXLarge
                        horizontalAlignment: HorizontalAlignment.Center
                        verticalAlignment: VerticalAlignment.Center
                    }
                    Label {
                        id: defaultLabel
                        text: qsTr("No new Hub activity yet...")
                        visible: !label.visible
                        multiline: true
                        textStyle.fontSize: FontSize.XXLarge
                        horizontalAlignment: HorizontalAlignment.Center
                        verticalAlignment: VerticalAlignment.Center
                    }
                }
            }
        }
   }
}